@@ -32,7 +32,7 @@
 #include <bonobo/bonobo-i18n.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
-#define EPHY_HISTORY_XML_VERSION "0.1"
+#define EPHY_HISTORY_XML_VERSION "1.0"
 
 /* how often to save the history, in milliseconds */
 #define HISTORY_SAVE_INTERVAL (60 * 5 * 1000)
@@ -201,7 +201,6 @@ ephy_history_load (EphyHistory *eb)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root, child;
-	char *tmp;
 
 	if (g_file_test (eb->priv->xml_file, G_FILE_TEST_EXISTS) == FALSE)
 		return;
@@ -211,10 +210,6 @@ ephy_history_load (EphyHistory *eb)
 
 	root = xmlDocGetRootElement (doc);
 
-	tmp = xmlGetProp (root, "version");
-	g_assert (tmp != NULL && strcmp (tmp, EPHY_HISTORY_XML_VERSION) == 0);
-	g_free (tmp);
-
 	for (child = root->children; child != NULL; child = child->next)
 	{
 		EphyNode *node;
@@ -419,7 +414,7 @@ ephy_history_init (EphyHistory *eb)
 
         eb->priv = g_new0 (EphyHistoryPrivate, 1);
 
-	db = ephy_node_db_new ("EphyHistory");
+	db = ephy_node_db_new (EPHY_NODE_DB_HISTORY);
 	eb->priv->db = db;
 
 	eb->priv->xml_file = g_build_filename (ephy_dot_dir (),
@@ -828,6 +823,26 @@ ephy_history_set_page_title (EphyHistory *gh,
 	g_value_unset (&value);
 }
 
+const char*
+ephy_history_get_icon (EphyHistory *gh,
+		       const char *url)
+{
+	EphyNode *node, *host;
+	int host_id;
+
+	node = ephy_history_get_page (gh, url);
+	if (node == NULL) return NULL;
+	
+	host_id = ephy_node_get_property_int (node, EPHY_NODE_PAGE_PROP_HOST_ID);
+	g_return_val_if_fail (host_id >= 0, NULL);
+
+	host = ephy_node_db_get_node_from_id (gh->priv->db, host_id);
+	g_return_val_if_fail (host != NULL, NULL);
+
+	return ephy_node_get_property_string (host, EPHY_NODE_PAGE_PROP_ICON);
+}	
+	
+		       
 void
 ephy_history_set_icon (EphyHistory *gh,
 		       const char *url,
